Description Usage Arguments Value Examples
This summary will calculate the following summary statistics for a given column in a dataset of interest: mean, median, max, min, standard deviation.
1 | summaryStats(dataset_of_interest, col_of_interest, export_results = FALSE)
|
dataset_of_interest |
The dataset of interest that the user wants to analyze. This parameter was named this way so that it is very clear to the user what the argument should be. |
col_of_interest |
The column of interest that want to calculate summary statistics for. This parameter was named this way so that it is very clear to the user what the argument should be. |
export_results |
Logical argument, where the default argument is FALSE. If the user inputs TRUE, a csv containing the calculated summary statiatics is created within the main directory. This parameter was named this way so that the user can determine whether or not they want to export results to a csv. |
A data frame that contains the summary statistics. If the user specifies TRUE for the third argument (export_results), then the function should also create a csv file.
1 2 3 | summaryStats(mtcars, hp)
summaryStats(iris, Sepal.Length)
summaryStats(PlantGrowth, weight)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.